#
# spec file for package wv
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global lname	libwv-1_2-4
Name:           wv
Version:        1.2.9
Release:        4.2
Summary:        Tools for Importing Microsoft Word (tm) Documents
License:        GPL-2.0-or-later
Group:          Productivity/Publishing/Word
URL:            http://wvware.sourceforge.net/
Source0:        https://www.abisource.com/downloads/%{name}/%{version}/%{name}-%{version}.tar.gz
Patch1:         detect-imagick.patch
Patch2:         man-refs.patch
Patch3:         man-wvrtf-name.patch
Patch4:         man-wvware-options.patch
Patch5:         non-latin-latex.patch
Patch6:         wvdvi-output-ext.patch
Patch7:         wvmime.patch
Patch8:         wvtext-no-graphics.patch
Patch9:         wvware-no-placeholder.patch
Patch10:        man-wvware-typo.patch
Patch11:        hardening-format.patch
Patch12:        man-remove-PU.patch
Patch13:        cross.patch
Patch14:        0014-Add-missing-include.patch
BuildRequires:  libexpat-devel
BuildRequires:  libjpeg-devel
BuildRequires:  libpng-devel
BuildRequires:  libtool
BuildRequires:  libwmf-devel
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(libgsf-1)
BuildRequires:  pkgconfig(libxml-2.0)
BuildRequires:  pkgconfig(zlib)
Requires:       w3m

%description
WV is a program that can understand the Microsoft Word 8 binary file
format (Office97). It currently converts Word into HTML, which can then
be read with a web browser.

%package -n %{lname}
Summary:        Library for importing Microsoft Word documents
Group:          System/Libraries

%description -n %{lname}
libwv can parse the Microsoft Word 8 binary file format (Office97).

%package devel
Summary:        Header files for wv
Group:          Development/Libraries/C and C++
Requires:       %{lname} = %{version}
Requires:       libgsf-devel
Requires:       libwmf-devel

%description devel
Header files for wv.

%prep
%autosetup -p1

%build
perl -i -lpe 's{AM_INIT_AUTOMAKE.*}{AM_INIT_AUTOMAKE([foreign subdir-objects])}g' configure.ac
autoreconf -f -i --verbose
%define warn_flags -Wall -Wstrict-prototypes -Wpointer-arith -Wformat -Wformat-security
CFLAGS="%{optflags} %{warn_flags} -fno-strict-aliasing -fstack-protector" \
%configure \
    --with-libwmf \
    --with-expat \
    --disable-dependency-tracking \
    --disable-static

%make_build

%install
%make_install manonedir=%{_mandir}/man1
find %{buildroot} -type f -name "*.la" -delete -print

%check
%make_build check

%ldconfig_scriptlets -n %{lname}

%files
%license COPYING
%doc README
%{_bindir}/wvAbw
%{_bindir}/wvCleanLatex
%{_bindir}/wvConvert
%{_bindir}/wvDVI
%{_bindir}/wvHtml
%{_bindir}/wvLatex
%{_bindir}/wvMime
%{_bindir}/wvPDF
%{_bindir}/wvPS
%{_bindir}/wvRTF
%{_bindir}/wvSummary
%{_bindir}/wvText
%{_bindir}/wvVersion
%{_bindir}/wvWare
%{_bindir}/wvWml
%{_bindir}/wvDocBook
%{_datadir}/wv
%{_mandir}/*/*

%files -n %{lname}
%{_libdir}/libwv-1.2.so.*

%files devel
%{_includedir}/wv
%{_libdir}/libwv.so
%{_libdir}/pkgconfig/%{name}-1.0.pc

%changelog
* Thu Nov 14 2024 Jan Engelhardt <jengelh@inai.de>
- Delete wv-1.0.3-wvText.patch, wv-1.2.2-automake.patch,
  wv-1.2.2-fiximplicit.patch, wv-gsf.patch, wv-noansi.patch,
  wv-strcasecmp.patch
- Add patches from Debian: 0014-Add-missing-include.patch,
  cross.patch, detect-imagick.patch, hardening-format.patch,
  man-refs.patch, man-remove-PU.patch, man-wvrtf-name.patch,
  man-wvware-options.patch, man-wvware-typo.patch,
  non-latin-latex.patch, wvdvi-output-ext.patch, wvmime.patch,
  wvtext-no-graphics.patch, wvware-no-placeholder.patch
* Tue Feb 20 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%patch -P N instead of deprecated %%patchN.
* Tue May 18 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Fix build: add explicit BuildRequires for libexpat-devel,
  libjpeg-devel, and libpng-devel.
* Mon Feb  5 2018 jengelh@inai.de
- --with-pic has no effect with --disable-static.
- Reword description of wv-devel since there are no static libs.
* Sat Feb  3 2018 avindra@opensuse.org
- Update to 1.2.9
  * fixes BC break from 1.2.8
- includes 1.2.8
  * Fix segfault trying to parse certain word documents
  * Fix Tables not imported from MS Word documents
  * Fix wvWare hangs on this seemingly blank word doc
  * Buildfix: Remove unused LINK_WIN32_DLL check
  * Buildfix: link with -no-undefined
- includes 1.2.7
  * Fix regression: newlines not imported anymore
  * Cross building improvements
  * Fix build issue: 'libtool: link: `-::-' is not valid version
    information'
- includes 1.2.6
  * unportable test construct.
  * Fix typos in wvWare's help message.
  * Fix a few mis-matched wvMalloc/malloc/wvFree/free combinations.
    Use glib to allocate and free all of our memory.
  * a NULL pointer was causing a crash.
  * Default font alignment in paragraph was incorrect.
  * Crash in the PAP handling.
  * Fix a memory leak in wvRTF.
  * Fix huge performance issue while loading images
  * Fix invalid writes in wvConfig.c
- cleanup with spec-cleaner
- use new upstream url
- rebase wv-1.2.2-automake.patch
- rebase wv-1.0.3-wvText.patch
- drop wv-1.0.3-pc.patch (applied upstream)
* Tue Oct  8 2013 mvyskocil@suse.com
- Fix Source URL
* Fri Oct  4 2013 mvyskocil@suse.com
- Update to 1.2.4 (no changelog available)
  * bump soname to libwv-1.2.so.3
- Dropped wv-1.2.2-overflow.patch, fixed upstream
- Reformat spec file, added Source url and URL, use  more macros
  and use pkgconfig() based BuildRequires
* Wed Aug 28 2013 crrodriguez@opensuse.org
- Also, cleanup buildrequires, libtiff is not used  and zlib-devel
  is required.
* Wed Aug 28 2013 crrodriguez@opensuse.org
- wv-noansi.patch: Do not build with -ansi , but in gnu99 mode with
  system extensions enabled
* Sat Apr 13 2013 dimstar@opensuse.org
- Add wv-strcasecmp.patch: Fix build in Factory: strcasecmp is
  declared in strings.h.
- Add wv-gsf.patch: only include gsf.h: we don't want/need to know
  in which header which symbold is declared.
* Tue Nov 22 2011 jengelh@medozas.de
- Correct License: field and use SPDX format (bnc#731983)
* Tue Nov 15 2011 jengelh@medozas.de
- Remove redundant/unwanted tags/section (cf. specfile guidelines)
- Use %%_smp_mflags for parallel building
- Apply shared library packaging (-> libwv-1_2 subpackage)
* Tue Nov 15 2011 coolo@suse.com
- add libtool as buildrequire to avoid implicit dependency
* Tue Oct 27 2009 meissner@suse.de
- fixed implicit strcasecmp caused by -ansi compile switch
- removed obsoletes/provides mswordvw (unversioned obsoletes, and
  also old package gone since 2000)
* Fri Jun 27 2008 crrodriguez@suse.de
- disable unusable static libraries
* Wed Jan 17 2007 joeshaw@suse.de
- Update to 1.2.2.  It requires libgsf and glib2 now, and I've
  updated some patches and dropepd others.
* Wed Nov 15 2006 prusnak@suse.cz
- fixed VUL-0: overflow (overflow.patch) [#215612]
* Sat Oct 21 2006 dmueller@suse.de
- build against system expat to reduce code size
* Thu Jan 26 2006 nadvornik@suse.cz
- fixed libdir in pkgconfig file [#115679]
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Thu Jan 12 2006 nadvornik@suse.cz
- compile with -fstack-protector
* Wed Aug  3 2005 gekker@suse.de
- Fix to open files RO rather than RW
* Mon Feb  7 2005 nadvornik@suse.cz
- updated to 1.0.3
* Thu Nov 11 2004 sbrabec@suse.cz
- Fixed buffer overflow in the wvHandleDateTimePicture function in wv
  library: CAN-2004-0645 (#47767).
* Tue Mar 30 2004 nadvornik@suse.cz
- prefer w3m in wvText as it handles UTF-8 output better
- better temp file handling in wvText
* Fri Feb 13 2004 meissner@suse.de
- fixed pkgconfig path.
* Thu Feb 12 2004 ro@suse.de
- added directory /usr/include/wv to devel filelist
* Wed Feb 11 2004 nadvornik@suse.cz
- updated to 1.0.0
- compile with -fno-strict-aliasing
* Sat Jan 10 2004 adrian@suse.de
- add %%run_ldconfig
* Mon Jul 28 2003 nadvornik@suse.cz
- updated to 0.7.6
* Wed Jun 18 2003 nadvornik@suse.cz
- fixed to compile with new libwmf
* Thu May 29 2003 nadvornik@suse.cz
- packaged wv.h
* Wed Sep 11 2002 ro@suse.de
- fixed patch (my fault)
* Wed Sep 11 2002 pthomas@suse.de
- Make wvText output to stdout on request.
- Add missing itmes to my last entry.
* Wed Sep 11 2002 ro@suse.de
- fixed requires of devel-package
* Tue Sep 10 2002 pthomas@suse.de
- Change wvText to use either w3m or lynx.
- wv-devel requires wv of same version.
- Require w3m
- Filter out /usr/include from CPPFLAGS.
- Don't patch config.h.in but instead call autoheader to
  regenerate it.
* Fri Jul 26 2002 adrian@suse.de
- fix neededforbuild
* Thu Jun 20 2002 nadvornik@suse.cz
- update to 0.7.2
* Fri Apr  5 2002 nadvornik@suse.cz
- fixed instalation of manpages
* Thu Apr  4 2002 nadvornik@suse.cz
- fixed to compile with new autoconf
* Fri Mar  8 2002 nadvornik@suse.cz
- fixed permissions and removed CVS dirs in doc directory
* Thu Feb  7 2002 nadvornik@suse.cz
- update to 0.7.1:
  - built with shared library
* Thu Jan 31 2002 ro@suse.de
- changed neededforbuild <libpng> to <libpng-devel-packages>
* Wed Nov 28 2001 nadvornik@suse.cz
- update to 0.7.0:
  - compiles with libwmf 0.2.2
* Thu Jun 28 2001 nadvornik@suse.cz
- update to 0.6.5
- libwmf is now a separate package
* Wed Jun 13 2001 nadvornik@suse.cz
- fixed to compile with new autoconf
* Fri May 18 2001 nadvornik@suse.cz
- fixed cast warnings and include files for ia64
* Mon Apr 23 2001 nadvornik@suse.cz
- fixed to compile on s390
* Mon Mar 12 2001 nadvornik@suse.cz
- libwmf compiled with -fPIC, now it can be linked to
  ImageMagick module
* Thu Feb  8 2001 nadvornik@suse.cz
- update wv to 0.6.4, libwmf to 0.1.21
- fixed bug #6165
* Wed Nov 22 2000 nadvornik@suse.cz
- fixed docdir name
* Tue Nov 21 2000 schwab@suse.de
- Fix permissions.
- Remove all CVS directories.
- Avoid double slashes.
* Fri Nov 10 2000 nadvornik@suse.cz
- rename mswordvw -> wv
-        mswordvd -> wv-devel
- update wv to 0.6.2, libwmf to 0.1.20
* Wed Nov  8 2000 ro@suse.de
- fixed neededforbuild for ImageMagick
* Mon Oct  9 2000 nadvornik@suse.cz
- fixed Copyright
- used bzip2
* Mon Sep 18 2000 nadvornik@suse.cz
- added magickd to neededforbuild
- fixed to compile
* Mon Jun 19 2000 nadvornik@suse.cz
- update to 0.5.44
* Mon Jun  5 2000 nadvornik@suse.cz
- fixed to compile with ImageMagick-5.2.0
* Fri May 26 2000 schwab@suse.de
- Update config files.
* Thu May 18 2000 nadvornik@suse.cz
- used %%{_defaultdocdir}
* Tue May  2 2000 nadvornik@suse.cz
- fixed to compile
* Thu Apr 20 2000 nadvornik@suse.cz
- fixed filelist
- created development subpackage mswordvd
* Tue Apr 18 2000 nadvornik@suse.cz
- update to 0.5.43, libwmf 0.1.17
- added Buildroot
* Mon Jan 31 2000 kukuk@suse.de
- Update to 0.5.14-bw6
- Fix spec file
- Move /usr/man -> /usr/share/man
* Mon Sep 13 1999 bs@suse.de
- ran old prepare_spec on spec file to switch to new prepare_spec.
* Wed Aug  4 1999 uli@suse.de
- added some missing files
* Fri May 21 1999 kukuk@suse.de
- Update mswordview to 0.5.14
* Thu Apr 29 1999 kukuk@suse.de
- first initial version of mswordview 0.5.10 with libwmf 0.1.9
